@@ -7,10 +7,16 @@
 #include <QApplication>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
+#include <QIcon>
 #include <QQmlApplicationEngine>
+#include <QQuickStyle>
 #include <QUrl>
 #include <QtQml>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QtWebEngine>
+#else
+#include <QtWebEngineQuick>
+#endif
 
 #include <KAboutData>
 #include <KDesktopFile>
@@ -38,6 +44,12 @@ QString desktopFileDirectory()
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
+    // set default style and icon theme
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE") && QQuickStyle::name().isEmpty()) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QGuiApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
 
@@ -45,8 +57,18 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     // Setup QtWebEngine
     qputenv("QTWEBENGINE_DIALOG_SET", "QtQuickControls2");
-#if QT_VERSION > QT_VERSION_CHECK(5, 14, 0)
+    QString chromiumFlags;
+    if (AngelfishSettings::self()->webSmoothScrollingEnabled()) {
+        chromiumFlags.append(QStringLiteral(" --enable-smooth-scrolling"));
+    }
+    if (AngelfishSettings::self()->webDarkModeEnabled()) {
+        chromiumFlags.append(QStringLiteral(" --blink-settings=forceDarkModeEnabled=true"));
+    }
+    qputenv("QTWEBENGINE_CHROMIUM_FLAGS", chromiumFlags.toUtf8());
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QtWebEngine::initialize();
+#else
+    QtWebEngineQuick::initialize();
 #endif
 
     QApplication app(argc, argv);
