@@ -32,14 +32,18 @@ public:
 
     bool isBookmarked(const QString &url) const;
 
-signals:
+    inline DBManager *databaseManager() {
+        return m_dbmanager;
+    }
+
+Q_SIGNALS:
     void updated();
 
     void initialUrlChanged();
 
     void databaseTableChanged(QString table);
 
-public slots:
+public Q_SLOTS:
     void addBookmark(const QVariantMap &bookmarkdata);
     void removeBookmark(const QString &url);
 
@@ -50,6 +54,9 @@ public slots:
     void updateLastVisited(const QString &url);
     void updateIcon(const QString &url, const QString &iconSource);
 
+    QString tempDirectory() const;
+    QString downloadDirectory() const;
+
 private:
     // BrowserManager should only be createdd by calling the instance() function
     BrowserManager(QObject *parent = nullptr);
