@@ -9,6 +9,7 @@
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 #include <QQmlApplicationEngine>
+#include <QQuickStyle>
 #include <QQuickWindow>
 #include <QUrl>
 #include <QtQml>
@@ -50,11 +51,25 @@ constexpr auto APPLICATION_ID = "org.kde.angelfish";
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
+    // set default style and icon theme
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE") && QQuickStyle::name().isEmpty()) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QGuiApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
 
     // Setup QtWebEngine
     qputenv("QTWEBENGINE_DIALOG_SET", "QtQuickControls2");
+    QString chromiumFlags;
+    if (AngelfishSettings::self()->webSmoothScrollingEnabled()) {
+        chromiumFlags.append(QStringLiteral(" --enable-smooth-scrolling"));
+    }
+    if (AngelfishSettings::self()->webDarkModeEnabled()) {
+        chromiumFlags.append(QStringLiteral(" --blink-settings=forceDarkModeEnabled=true"));
+    }
+    qputenv("QTWEBENGINE_CHROMIUM_FLAGS", chromiumFlags.toUtf8());
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QtWebEngine::initialize();
 #else
